==> nuance-gulp-build-0.0.19.tgz: package/index.js <==
const through = require('through2');
const fs = require('fs');

const builders = {
    dotnet: require('./builders/dotnet')
};

const bumpers = {
    csproj17: require('./bumpers/csproj17'),
    project_json: require('./bumpers/project-json')
};

const versioners = {
    gitlab: function (cfg) {

        var version = "";

        var shouldUseRefname = /(feature|bugfix|hotfix|release)(\d*)-(\d+\.\d+\.\d+)/;
        var useTag = /v(\d+\.\d+\.\d+)/;
        var version = "";

        if (shouldUseRefname.test(cfg.refname)) {
            console.log('using refname as version')
            cfg.useRefNameForVersion = true;
            cfg.useTagForVersion = false;
            var r = shouldUseRefname.exec(cfg.refname);
            if (r[2] == null) {
                return `${r[3]}-${r[1]}-${cfg.autoVersion}`;

            }
            return `${r[3]}-${r[1]}${r[2]}-${cfg.autoVersion}`;
        }
        else if (useTag.test(cfg.refname)) {
            cfg.useTagForVersion = true;
            cfg.useRefNameForVersion = false;
            var r = useTag.exec(cfg.refname);
            return r[1];
        }

        cfg.useTagForVersion = false;
        cfg.useRefNameForVersion = false;
    },

    gitflow: function (cfg) {

        var version = "";
        var shouldUseRefname = /(hotfix|feature|bugfix|release)\/(\d*)-(\d+\.\d+\.\d+)/;
        var useTag = /v(\d+.\d+.\d+)/;

        if (shouldUseRefname.test(cfg.refname)) {
            console.log('using refname as version')
            cfg.useRefNameForVersion = true;
            cfg.useTagForVersion = false;
            var r = shouldUseRefname.exec(cfg.refname);
            if (r[2] == null) {
                return `${r[3]}-${r[1]}-${cfg.autoVersion}`;

            }
            return `${r[3]}-${r[1]}${r[2]}-${cfg.autoVersion}`;
        }
        else if (useTag.test(cfg.refname)) {
            cfg.useTagForVersion = true;
            cfg.useRefNameForVersion = false;
            var r = useTag.exec(cfg.refname);
            return r[1];
        }

        cfg.useTagForVersion = false;
        cfg.useRefNameForVersion = false;
    }
}

const environments = {
    file: function (f) { return require('./environments/file')(f) },
    bitbucket: require('./environments/bitbucket'),
    gitlab: require('./environments/gitlab')
};

const packers = {
    dotnet: require('./packers/dotnet')
};

const publishers = {
    nuget: require('./publishers/nuget')
}

function parseBool(v) {
    return v.toString().toLowerCase() == "true";
}

async function bump() {
    return through.obj(async (file, enc, done) => {
        var p = file.file;
        
        var envConfig = file.configuration;
        var version = await makeversion(file.configuration);
        if (version == null) {
            console.log('bump was called but will not bump because version is null')
            return done();
        }
        await bumpers[file.bump_type](p, version);


        return done();
    });
};

async function build() {
    return through.obj(async (file, enc, done) => {
        await builders[file.build_mode](file, enc, done);
    });
}

async function pack() {
    return through.obj(async (file, enc, done) => {
        var packer = packers[file.pack_mode];
        await packer(file);
        done();
    })
}

async function push() {
    return through.obj(async (file, enc, done) => {
        if (parseBool(file.configuration.pushPackage)) {
            var publisher = publishers[file.publisher]
            await publisher(file);
        }
    })
}
async function makeversion(configuration, outputfile) {

    var version = versioners[configuration.versioner](configuration);
    return new Promise((ff, rej) => {
        if(outputfile == null) {
            return ff(version);
        }
        var ws = fs.createWriteStream(outputfile);
        ws.write(version, () => {
            ws.close();
            ff(version);

        });
    })
}



module.exports = {
    builders: builders,
    bumpers: bumpers,
    environments: environments,
    packers: packers,
    bump: bump,
    build: build,
    pack: pack,
    push: push,
    version: makeversion
}

==> nuance-gulp-build-0.0.19-37.tgz: package/index.js <==
const through = require('through2');
const fs = require('fs');

const builders = {
    dotnet: () => require('./lib/builders/dotnet')
};

const bumpers = {
    csproj17: () => require('./lib/bumpers/csproj17'),
    project_json: () => require('./lib/bumpers/project-json')
};

const versioners = {
    gitlab: function (cfg) {

        var version = "";

        var shouldUseRefname = /(feature|bugfix|hotfix|release)(\d*)-(\d+\.\d+\.\d+)/;
        var useTag = /v(\d+\.\d+\.\d+)/;
        var version = "";

        if (shouldUseRefname.test(cfg.refname)) {
            console.log('using refname as version')
            cfg.useRefNameForVersion = true;
            cfg.useTagForVersion = false;
            var r = shouldUseRefname.exec(cfg.refname);
            if (r[2] == null) {
                return `${r[3]}-${r[1]}-${cfg.autoVersion}`;

            }
            return `${r[3]}-${r[1]}${r[2]}-${cfg.autoVersion}`;
        }
        else if (useTag.test(cfg.refname)) {
            cfg.useTagForVersion = true;
            cfg.useRefNameForVersion = false;
            var r = useTag.exec(cfg.refname);
            return r[1];
        }

        cfg.useTagForVersion = false;
        cfg.useRefNameForVersion = false;
    },

    gitflow: function (cfg) {

        var version = "";
        var shouldUseRefname = /(hotfix|feature|bugfix|release)\/(\d*)-(\d+\.\d+\.\d+)/;
        var useTag = /v(\d+.\d+.\d+)/;

        if (shouldUseRefname.test(cfg.refname)) {
            console.log('using refname as version')
            cfg.useRefNameForVersion = true;
            cfg.useTagForVersion = false;
            var r = shouldUseRefname.exec(cfg.refname);
            if (r[2] == null) {
                return `${r[3]}-${r[1]}-${cfg.autoVersion}`;

            }
            return `${r[3]}-${r[1]}${r[2]}-${cfg.autoVersion}`;
        }
        else if (useTag.test(cfg.refname)) {
            cfg.useTagForVersion = true;
            cfg.useRefNameForVersion = false;
            var r = useTag.exec(cfg.refname);
            return r[1];
        }

        cfg.useTagForVersion = false;
        cfg.useRefNameForVersion = false;
    }
}

const environments = {
    file: (f) => require('./lib/environments/file')(f),
    bitbucket: () => require('./lib/environments/bitbucket'),
    gitlab: () => require('./lib/environments/gitlab')
};

const packers = {
    dotnet: () => require('./lib/packers/dotnet')
};

const publishers = {
    nuget: () => require('./lib/publishers/nuget')
}

function parseBool(v) {
    return v.toString().toLowerCase() == "true";
}

function bump() {
    return through.obj((file, enc, done) => {
        var p = file.file;

        var envConfig = file.configuration;
        makeversion(file.configuration).then(version => {
            if (version == null) {
                console.log('bump was called but will not bump because version is null')
                return done();
            }
            bumpers[file.bump_type]()(p, version, done);
        });
    });
};

function build() {
    return through.obj((file, enc, done) => {
        builders[file.build_mode]()(file, enc, done);
    });
}

function pack() {
    return through.obj((file, enc, done) => {
        var packer = packers[file.pack_mode]();
        packer(file, done);
    })
}

function push() {
    return through.obj((file, enc, done) => {
        var publisher = publishers[file.publisher]()
        publisher(file, done);
    })
}
async function makeversion(configuration, outputfile) {

    var version = versioners[configuration.versioner](configuration);
    return new Promise((ff, rej) => {
        if (outputfile == null) {
            return ff(version);
        }
        var ws = fs.createWriteStream(outputfile);
        ws.write(version, () => {
            ws.close();
            ff(version);
        });
    })
}

module.exports = {
    builders: builders,
    bumpers: bumpers,
    environments: environments,
    packers: packers,
    bump: bump,
    build: build,
    pack: pack,
    push: push,
    version: makeversion
}
